@@ -17,6 +17,7 @@ from scipy.fft import fft, fftfreq
 import NAFFlib # Numerical Analysis of the Fundamental Frequencies 
 
 # Define plotting parameters
+plt.rcParams.update({'font.family':'DejaVu Sans'})
 mpl.rcParams['axes.labelsize'] = 20
 mpl.rcParams['xtick.labelsize'] = 14
 mpl.rcParams['ytick.labelsize'] = 14
@@ -447,9 +448,8 @@ class particles:
         """ 
         Method to calculate classical particle radius from given reference particle, also ions
         """
-        q = 1.602176634e-19 # elementary charge 
         m0 = particle_ref.mass0*1.782661921e-36  # electron volt - kg conversion
-        r0 = (particle_ref.q0*q)**2/(4*np.pi*constants.epsilon_0*m0*constants.c**2)  #1.5347e-18 is default for protons
+        r0 = (particle_ref.q0**constants.elementary_charge)**2/(4*np.pi*constants.epsilon_0*m0*constants.c**2)  #1.5347e-18 is default for protons
         return r0
 
 
